from __future__ import annotations

def get(path) -> oscoutput:
   pass

class oscoutput:
   def send_float(this, address, val):
      pass

   def send_int(this, address, val):
      pass

   def send_string(this, address, val):
      pass

