from __future__ import annotations

def get(path) -> notesequencer:
   pass

class notesequencer:
   def set_step(this, step, row, velocity = 127, length = 1.0):
      pass

   def set_pitch(this, step, pitch, velocity = 127, length = 1.0):
      pass

