from __future__ import annotations

def get(path) -> linnstrument:
   pass

class linnstrument:
   def set_color(this, x, y, color):
      pass

   Off: ...
   Red: ...
   Yellow: ...
   Green: ...
   Cyan: ...
   Blue: ...
   Magenta: ...
   Black: ...
   White: ...
   Orange: ...
   Lime: ...
   Pink: ...
