from __future__ import annotations

def get(path) -> sampleplayer:
   pass

class sampleplayer:
   def set_cue_point(this, pitch, startSeconds, lengthSeconds, speed):
      pass

   def fill(this, data):
      pass

   def play_cue(this, cue, speedMult = 1, startOffsetSeconds = 0):
      pass

   def get_length_seconds(this, ):
      pass

