from __future__ import annotations

def get(path) -> notecanvas:
   pass

class notecanvas:
   def add_note(this, measurePos, pitch, velocity, length):
      pass

   def clear(this, ):
      pass

   def fit(this, ):
      pass

