from __future__ import annotations

def get_measure_time():
   pass

def get_measure():
   pass

def reset_transport():
   pass

def get_step(subdivision):
   pass

def count_per_measure(subdivision):
   pass

def time_until_subdivision(subdivision):
   pass

def get_time_sig_ratio():
   pass

def get_root():
   pass

def get_scale():
   pass

def get_scale_range(octave, count):
   pass

def tone_to_pitch(index):
   pass

def name_to_pitch(noteName):
   pass

def pitch_to_name(pitch):
   pass

def pitch_to_freq(pitch):
   pass

def get_tempo():
   pass

def set_background_text(str, size=50, xPos = 150, yPos = 250, red = 1, green = 1, blue = 1):
   pass

def random(seed, index):
   pass

def get_modules():
   pass

