from __future__ import annotations

def get(path) -> vstplugin:
   pass

class vstplugin:
   def send_cc(this, ctl, value, channel):
      pass

   def send_program_change(this, program, channel):
      pass

   def send_data(this, a, b, c):
      pass

