from __future__ import annotations

def get(path) -> grid:
   pass

class grid:
   def set(this, col, row, value):
      pass

   def get(this, col, row):
      pass

   def set_grid(this, cols, rows):
      pass

   def set_label(this, row, label):
      pass

   def set_color(this, colorIndex, r, g, b):
      pass

   def highlight_cell(this, col, row, delay, duration, colorIndex=1):
      pass

   def set_division(this, division):
      pass

   def set_momentary(this, momentary):
      pass

   def set_cell_color(this, col, row, colorIndex):
      pass

   def get_cell_color(this, col, row):
      pass

   def add_listener(this, script):
      pass

   def clear(this, ):
      pass

