from __future__ import annotations

def get(path) -> module:
   pass

def create(moduleType, x, y):
   pass

class module:
   def set_position(this, x, y):
      pass

   def get_position_x(this, ):
      pass

   def get_position_y(this, ):
      pass

   def get_width(this, ):
      pass

   def get_height(this, ):
      pass

   def set_target(this, target):
      pass

   def set_target(this, targetPath):
      pass

   def get_target(this, ):
      pass

   def get_targets(this, ):
      pass

   def set_name(this, name):
      pass

   def delete(this, ):
      pass

   def set(this, path, value):
      pass

   def get(this, path):
      pass

   def adjust(this, path, amount):
      pass

